{
  pkgs,
  config,
  buildRoot,
  projectDefinition,
  ...
}: let
common = import "${./common.nix}" {inherit pkgs;};
  taskfileYaml = import ../config/taskfile.nix {
    inherit pkgs config buildRoot projectDefinition;
  };
  gitlabCiYaml = import ../config/gitlab-ci.nix {
    inherit pkgs config buildRoot projectDefinition;
  };
  serviceSourcePath = "${buildRoot}/";
in ''
  #!${pkgs.bash}/bin/bash
   ${common}

   ## updfate-files should called by direnv and the first argument is the path to the project root
   workingRoot="''${1:-''${PWD}}"


    if [[ ! -f "''${workingRoot}/flake.nix" ]]; then
         echo_fail "No flake.nix found in ''${workingRoot}"
         exit 1
    fi


  create_symlink() {
      if ln -s "$1" "$2" 2>/dev/null; then
          echo_ok "$2 created"
      else
          echo_fail "$2 already exists"
      fi
  }

  update_symlink() {
      local source_path="$1"
      local target_path="$2"
      local file_name="$(basename "$target_path")"
      local source_dir="$(dirname "$source_path")"
      mkdir -p "$source_dir" || true
      if [[ ! -d "$source_dir" ]]; then
          echo_fail "$source_dir is not a directory. Please remove it manually and run the script again."
          exit 1
      fi

      if [[ -L "$source_path" ]]; then
          if [[ "$(readlink "$source_path")" != "$target_path" ]]; then
              echo_step "Remove old symlink $file_name"
              rm "$source_path"
              echo_step "Create new symlink $file_name"
              create_symlink "$target_path" "$source_path"
              echo_ok "$source_path updated$RESET"
          else
              echo_ok "$source_path is up to date$RESET"
          fi
      elif [[ -e "$source_path" ]]; then
          echo_fail "$source_path already exists and is not a symlink. Please remove it manually and run the script again."
          exit 1
      else
          create_symlink "$target_path" "$source_path"
          echo_ok "$source_path created$RESET"
      fi
  }

  update_symlink "''${workingRoot}/Taskfile.yaml" "${taskfileYaml}"

  ## copy, because the file must be exists in the source directory
  cat "${gitlabCiYaml}" > "''${workingRoot}/.gitlab-ci.yml"
  echo_ok ".gitlab-ci.yml updated"


''
